from django.db import models

class Lecturer(models.Model):
    first_name = models.CharField('Vorname', max_length = 50)
    last_name = models.CharField('Nachname', max_length = 50)
    description = models.TextField('Beschreibung')
    
    def __str__(self):
        return 'Lecturer %s %s' % (self.first_name, self.last_name)

    @models.permalink
    def get_absolute_url(self):
        return ('lecturer_details', [str(self.id)])

class Student(models.Model):
    first_name = models.CharField('Vorname', max_length = 50)
    last_name = models.CharField('Nachname', max_length = 50)
    mail = models.EmailField('eMail')
    matriculated_on = models.DateTimeField('Immatrikuliert am', auto_now_add = True)

    def __str__(self):
        return 'Student %s %s' % (self.first_name, self.last_name)

class Course(models.Model):
    title = models.CharField('Titel', max_length = 50)
    description = models.TextField('Beschreibung')
    lecturer = models.ForeignKey(Lecturer, related_name = 'courses')
    participants = models.ManyToManyField(Student, related_name = 'courses_taken', null = True, blank = True)

    def __str__(self):
        return 'Course %s' % (self.title)
